# stacksearch

[![Build Status](https://travis-ci.com/ThatXliner/stacksearch.svg?branch=master)](https://travis-ci.com/ThatXliner/stacksearch) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) ![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/ThatXliner/stacksearch) [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/ThatXliner/stacksearch/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/ThatXliner/stacksearch/?branch=master) [![Build Status](https://scrutinizer-ci.com/g/ThatXliner/stacksearch/badges/build.png?b=master)](https://scrutinizer-ci.com/g/ThatXliner/stacksearch/build-status/master)

StackSearch is a python module that provides a way to search StackOverflow. The reason this is better than other modules is that this module provides a modern API, a beautiful command-line interface via argparse and blessings, all in pure Python.

## Benefits

TK.

## Downsides

TK.

## Future Features

- Asynchronous StackOverflow requests
- Documentation
- Object-oriented APIs
- Python backwards-compatibility
- Being able to scrape _all_ StackOverflow sites/pages
- A better README
- And more command-line options

## Current Features

- A beautiful, simple, yet powerful command-line interface
- The ability to crank out raw JSON data to use
